/*!
    \defgroup sensor Sensor
    \brief Base class for Ctp3 sensors
*/
///@{

#pragma once

#include <spdlog/spdlog.h>
#include <vector>

///
/// \class ObSensor
///
/// \brief Base Obmon sensor class
///	\author Martin Vala <mvala@cern.ch>
///

class ObSensor {
public:

  /// Enums for sensor type
  enum class SensorType { VALUE, SPEED };

  ObSensor(std::string name = {"sensor"});
  virtual ~ObSensor();

  virtual void init();
  /// Process function
  virtual void process(){};
  /// Calculate time change (speed)
  virtual void speed(ObSensor * /*s1*/, ObSensor * /*s2*/,
                     int /*timeout*/){};
  virtual std::string json(const std::string name = {}) const;

  virtual void update(int timeout) final;

  /// Returns name of sensor
  std::string name() const { return _name; }

  /// Sets sensor type
  void type(SensorType t) { _type = t; }

  /// Returns sensor type
  SensorType type() const { return _type; }

  /// Return list of sensors
  std::vector<ObSensor *> &sensors() { return _sensors; }

protected:
  std::shared_ptr<spdlog::logger> _logger; ///< Pointer to spd logger
  std::string _name;                       ///< Sensor name
  SensorType _type;                        ///< Sensor type
  ObSensor *_first{};                    ///< Pointer to first sensor
  ObSensor *_second{};                   ///< Pointer to second sensor
  ObSensor *_change{};                   ///< Pointer to change sensor
  std::vector<ObSensor *> _sensors{};    ///< List of subsensors
};

///@}
