/*!
    \defgroup sensor Sensor
    \brief This module receives data from the computer.

     The module retrieves data about CPU, memory and network.
*/
///@{

#pragma once

#include <ObSensor.h>

#include <iostream>
#include <string>
#include <vector>

#include <glibtop/cpu.h>
#include <glibtop/mem.h>
#include <glibtop/netlist.h>
#include <glibtop/netload.h>

///
/// \class ObSensorSystem
///
/// \brief System Obmon sensor class
///	\author Martin Vala <mvala@cern.ch>
///

class ObSensorSystem : public ObSensor {
public:
  ObSensorSystem(std::string name = {"sys"});
  virtual ~ObSensorSystem();

  void init() override;
  void process() override;
  void speed(ObSensor *s1, ObSensor *s2, int timeout = 1000) override;
  std::string json(const std::string name = {"static"}) const override;

  /// returns glibtop_cpu
  glibtop_cpu cpu() const { return _cpu; }

  /// returns glibtop_mem
  glibtop_mem mem() const { return _mem; }

  /// returns glibtop_netlist
  glibtop_netlist netlist() const { return _netlist; }

  /// returns netloads
  std::vector<glibtop_netload *> netloads() const { return _netloads; }

private:
  glibtop_cpu _cpu{};                         ///< Cpu info from glitop
  glibtop_mem _mem{};                         ///< Mem info from glitop
  glibtop_netlist _netlist{};                 ///< NetList from glitop
  std::vector<glibtop_netload *> _netloads{}; ///< List of netload
  std::vector<std::string> _netnames{};       ///< list of network names
};

///@}
